PAWpySeed: pawpyseed.core.utils Namespace Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Namespace Members

Classes | Functions
pawpyseed.core.utils Namespace Reference

Miscellaneous utilities file for the Python portion of the code. More...

## Classes
class | PAWpyError
class | PAWpyWarning

## Functions
def | check_spin (spin, nspin)
def | el (site)

## Detailed Description

Miscellaneous utilities file for the Python portion of the code.

## Function Documentation

def pawpyseed.core.utils.check_spin | ( |  | spin,
|  |  | nspin
| ) |  |

    Utility to check if the spin input parameter to single_band_projection
    and similar functions is allowed given nspin of the wavefunction object
    being analyzed. Returns a new value of spin if spin must be changed,
    raises an error if spin is not allowed.

def pawpyseed.core.utils.el | ( |  | site | ) |

    Return the element symbol of a pymatgen
    site object